@@ -36,11 +36,11 @@ class MyTextWrapper(textwrap.TextWrapper):
         # Override wrapping regex, preserve '/' before linebreak
         self.wordsep_re = re.compile(
             u'('
-            u'[ \t\n\r\f\v]+|'                        # any ASCII whitespace
-            u'[^\\s\\w]*\\w+/(?=[A-Za-z]\\w*)|'               # forward-slash separated words
-            u'[^\\s\\w]*\\w+[^0-9\\W]-(?=\\w+[^0-9\\W])|'   # hyphenated words
-            u'''(?<=[\\w\\!"'\\&\\.\\,\\?])-{2,}(?=\\w))'''    # em-dash
-            u'(?![\u2060|\u200B])')                   # UNLESS &wj; or &zwbs; or &nbsp;
+            u'[ \t\n\r\f\v]+|'                                  # any ASCII whitespace
+            u'[^\\s-]*\\w+/(?=[A-Za-z]\\w*)|'                   # forward-slash separated words
+            u'[^\\s-]*\\w+[^0-9\\s]-(?=\\w+[^0-9\\s])|'         # hyphenated words
+            u'''(?<=[\\w\\!"'\\&\\.\\,\\?])-{2,}(?=\\w))'''     # em-dash
+            u'(?![\u2060|\u200B])')                             # UNLESS &wj; or &zwbs; or &nbsp;
 
         self.wordsep_re_uni = re.compile(self.wordsep_re.pattern, re.U)
 
