@@ -334,7 +334,9 @@ class RawTextRfcWriter(BaseRfcWriter):
         tmpbuf = self.pre_write_iref_index()
         # Sort iref items alphabetically, store by first letter 
         alpha_bucket = {}
-        for key in sorted(self._iref_index.keys()):
+        keys = list(self._iref_index.keys())
+        keys.sort(key=str.upper)
+        for key in keys:
             letter = key[0].upper()
             if letter in alpha_bucket:
                 alpha_bucket[letter].append(key)
@@ -348,7 +350,9 @@ class RawTextRfcWriter(BaseRfcWriter):
                 # Write item
                 self.write_text(item + '  ' + pagelist(pages)
                                                         , indent=6, buf=tmpbuf, fix_doublespace=False)
-                for subitem in sorted(self._iref_index[item].subitems.keys()):
+                subkeys = list(self._iref_index[item].subitems.keys())
+                subkeys.sort(key=str.upper)
+                for subitem in subkeys:
                     pages = set(self._iref_index[item].subitems[subitem].pages)
                     # Write subitem
                     self.write_text(subitem + '  ' + pagelist(pages)
@@ -934,7 +938,8 @@ class RawTextRfcWriter(BaseRfcWriter):
             #  ??????????????
             ttcol_widths = inf
         elif table_max_chars < sum(longest_words):
-            xml2rfc.log.warn("so many <ttcol>s in <texttable> that some words need to be split near line %s" % table.sourceline)
+            if not self.indexmode:
+                xml2rfc.log.warn("so many <ttcol>s in <texttable> that some words need to be split near line %s" % table.sourceline)
 
             excess = sum(longest_words) - table_max_chars
 
